@@ -56,9 +56,8 @@ from pkg_resources import (
 )
 from setuptools import Command
 from setuptools.archive_util import unpack_archive
-from setuptools.command import bdist_egg, egg_info, setopt
+from setuptools.command import bdist_egg, setopt
 from setuptools.package_index import URL_SCHEME, PackageIndex, parse_requirement_arg
-from setuptools.sandbox import run_setup
 from setuptools.warnings import SetuptoolsDeprecationWarning, SetuptoolsWarning
 from setuptools.wheel import Wheel
 
@@ -132,8 +131,8 @@ class easy_install(Command):
         (
             'optimize=',
             'O',
-            "also compile with optimization: -O1 for \"python -O\", "
-            "-O2 for \"python -OO\", and -O0 to disable [default: -O0]",
+            'also compile with optimization: -O1 for "python -O", '
+            '-O2 for "python -OO", and -O0 to disable [default: -O0]',
         ),
         ('record=', None, "filename in which to record list of installed files"),
         ('always-unzip', 'Z', "don't install as a zipfile, no matter what"),
@@ -148,7 +147,7 @@ class easy_install(Command):
             None,
             "Don't load find-links defined in packages being installed",
         ),
-        ('user', None, "install in user site-package '%s'" % site.USER_SITE),
+        ('user', None, f"install in user site-package '{site.USER_SITE}'"),
     ]
     boolean_options = [
         'zip-ok',
@@ -424,33 +423,7 @@ class easy_install(Command):
         self._expand_attrs(dirs)
 
     def run(self, show_deprecation: bool = True) -> None:
-        if show_deprecation:
-            self.announce(
-                "WARNING: The easy_install command is deprecated "
-                "and will be removed in a future version.",
-                log.WARN,
-            )
-        if self.verbose != self.distribution.verbose:
-            log.set_verbosity(self.verbose)
-        try:
-            for spec in self.args:
-                self.easy_install(spec, not self.no_deps)
-            if self.record:
-                outputs = self.outputs
-                if self.root:  # strip any package prefix
-                    root_len = len(self.root)
-                    for counter in range(len(outputs)):
-                        outputs[counter] = outputs[counter][root_len:]
-                from distutils import file_util
-
-                self.execute(
-                    file_util.write_file,
-                    (self.record, outputs),
-                    "writing list of installed files to '%s'" % self.record,
-                )
-            self.warn_deprecated_options()
-        finally:
-            log.set_verbosity(self.distribution.verbose)
+        raise RuntimeError("easy_install command is disabled")
 
     def pseudo_tempname(self):
         """Return a pseudo-tempname base in the install directory.
@@ -461,7 +434,7 @@ class easy_install(Command):
             pid = os.getpid()
         except Exception:
             pid = random.randint(0, sys.maxsize)
-        return os.path.join(self.install_dir, "test-easy-install-%s" % pid)
+        return os.path.join(self.install_dir, f"test-easy-install-{pid}")
 
     def warn_deprecated_options(self) -> None:
         pass
@@ -649,8 +622,8 @@ class easy_install(Command):
     def not_editable(self, spec) -> None:
         if self.editable:
             raise DistutilsArgError(
-                "Invalid argument %r: you can't use filenames or URLs "
-                "with --editable (except via the --find-links option)." % (spec,)
+                f"Invalid argument {spec!r}: you can't use filenames or URLs "
+                "with --editable (except via the --find-links option)."
             )
 
     def check_editable(self, spec) -> None:
@@ -659,8 +632,7 @@ class easy_install(Command):
 
         if os.path.exists(os.path.join(self.build_directory, spec.key)):
             raise DistutilsArgError(
-                "%r already exists in %s; can't do a checkout there"
-                % (spec.key, self.build_directory)
+                f"{spec.key!r} already exists in {self.build_directory}; can't do a checkout there"
             )
 
     @contextlib.contextmanager
@@ -698,7 +670,7 @@ class easy_install(Command):
                 self.local_index,
             )
             if dist is None:
-                msg = "Could not find suitable distribution for %r" % spec
+                msg = f"Could not find suitable distribution for {spec!r}"
                 if self.always_copy:
                     msg += " (--always-copy skips system and development eggs)"
                 raise DistutilsError(msg)
@@ -917,12 +889,11 @@ class easy_install(Command):
             setups = glob(os.path.join(setup_base, '*', 'setup.py'))
             if not setups:
                 raise DistutilsError(
-                    "Couldn't find a setup script in %s"
-                    % os.path.abspath(dist_filename)
+                    f"Couldn't find a setup script in {os.path.abspath(dist_filename)}"
                 )
             if len(setups) > 1:
                 raise DistutilsError(
-                    "Multiple setup scripts in %s" % os.path.abspath(dist_filename)
+                    f"Multiple setup scripts in {os.path.abspath(dist_filename)}"
                 )
             setup_script = setups[0]
 
@@ -1000,7 +971,7 @@ class easy_install(Command):
         cfg = extract_wininst_cfg(dist_filename)
         if cfg is None:
             raise DistutilsError(
-                "%s is not a valid distutils Windows .exe" % dist_filename
+                f"{dist_filename} is not a valid distutils Windows .exe"
             )
         # Create a dummy distribution object until we build the real distro
         dist = Distribution(
@@ -1026,7 +997,8 @@ class easy_install(Command):
                 f.write('Metadata-Version: 1.0\n')
                 for k, v in cfg.items('metadata'):
                     if k != 'target_version':
-                        f.write('%s: %s\n' % (k.replace('_', '-').title(), v))
+                        k = k.replace('_', '-').title()
+                        f.write(f'{k}: {v}\n')
         script_dir = os.path.join(_egg_info, 'scripts')
         # delete entry-point scripts to avoid duping
         self.delete_blockers([
@@ -1114,8 +1086,9 @@ class easy_install(Command):
             self.execute(
                 wheel.install_as_egg,
                 (destination,),
-                ("Installing %s to %s")
-                % (os.path.basename(wheel_path), os.path.dirname(destination)),
+                (
+                    f"Installing {os.path.basename(wheel_path)} to {os.path.dirname(destination)}"
+                ),
             )
         finally:
             update_dist_caches(destination, fix_zipimporter_caches=False)
@@ -1175,23 +1148,8 @@ class easy_install(Command):
         python = sys.executable
         return '\n' + self.__editable_msg % locals()
 
-    def run_setup(self, setup_script, setup_base, args) -> None:
-        sys.modules.setdefault('distutils.command.bdist_egg', bdist_egg)
-        sys.modules.setdefault('distutils.command.egg_info', egg_info)
-
-        args = list(args)
-        if self.verbose > 2:
-            v = 'v' * (self.verbose - 1)
-            args.insert(0, '-' + v)
-        elif self.verbose < 2:
-            args.insert(0, '-q')
-        if self.dry_run:
-            args.insert(0, '-n')
-        log.info("Running %s %s", setup_script[len(setup_base) + 1 :], ' '.join(args))
-        try:
-            run_setup(setup_script, args)
-        except SystemExit as v:
-            raise DistutilsError("Setup script exited with %s" % (v.args[0],)) from v
+    def run_setup(self, setup_script, setup_base, args) -> NoReturn:
+        raise NotImplementedError("easy_install support has been removed")
 
     def build_and_install(self, setup_script, setup_base):
         args = ['bdist_egg', '--dist-dir']
@@ -1374,7 +1332,7 @@ class easy_install(Command):
         home = convert_path(os.path.expanduser("~"))
         for path in only_strs(self.config_vars.values()):
             if path.startswith(home) and not os.path.isdir(path):
-                self.debug_print("os.makedirs('%s', 0o700)" % path)
+                self.debug_print(f"os.makedirs('{path}', 0o700)")
                 os.makedirs(path, 0o700)
 
     INSTALL_SCHEMES = dict(
@@ -1599,7 +1557,7 @@ def get_exe_prefixes(exe_filename):
                 for pth in yield_lines(contents):
                     pth = pth.strip().replace('\\', '/')
                     if not pth.startswith('import'):
-                        prefixes.append((('%s/%s/' % (parts[0], pth)), ''))
+                        prefixes.append(((f'{parts[0]}/{pth}/'), ''))
     finally:
         z.close()
     prefixes = [(x.lower(), y) for x, y in prefixes]
@@ -2305,7 +2263,7 @@ def get_win_launcher(type):
 
     Returns the executable as a byte string.
     """
-    launcher_fn = '%s.exe' % type
+    launcher_fn = f'{type}.exe'
     if is_64bit():
         if get_platform() == "win-arm64":
             launcher_fn = launcher_fn.replace(".", "-arm64.")
